antic: Algebraic Number Theory In C
===================================

Description
-----------

Algebraic Number Theory In C

License
-------

LGPL 2.1

Upstream Contact
----------------

https://github.com/wbhart/antic

